==> haskell-crypton-x509-system-1.6.7-136-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-x509-system.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-x509-system
version:              1.6.7
visibility:           public
id:                   crypton-x509-system-1.6.7-AlhozJnZLRBLBROfMMJw3u
key:                  crypton-x509-system-1.6.7-AlhozJnZLRBLBROfMMJw3u
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/kazu-yamamoto/crypton-certificate
synopsis:             Handle per-operating-system X.509 accessors and storage
description:
    System X.509 handling for accessing operating system dependents store and other storage methods

category:             Data
abi:                  b1d841a0f92d9eb72743a2e0489c5933
exposed:              True
exposed-modules:      System.X509 System.X509.MacOS System.X509.Unix
import-dirs:          /usr/lib/ghc-9.6.6/site-local/crypton-x509-system-1.6.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/crypton-x509-system-1.6.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/crypton-x509-system-1.6.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-x509-system
hs-libraries:         HScrypton-x509-system-1.6.7-AlhozJnZLRBLBROfMMJw3u
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    crypton-x509-1.7.7-36kCqNSNK3p1rkA4mLjsoT
    crypton-x509-store-1.6.12-8u0cMDz1Er0H0crmNaS9QT directory-1.3.8.5
    filepath-1.4.300.1 mtl-2.3.1 pem-0.2.4-BtvjegbjHoRAGAf9oBrW3C
    process-1.6.19.0

haddock-interfaces:
    /usr/share/doc/haskell-crypton-x509-system/html/crypton-x509-system.haddock

haddock-html:         /usr/share/doc/haskell-crypton-x509-system/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypton-x509-system-1.6.7-137-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-x509-system.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-x509-system
version:              1.6.7
visibility:           public
id:                   crypton-x509-system-1.6.7-DQHBNlA1dz6FrhIVkM7QX0
key:                  crypton-x509-system-1.6.7-DQHBNlA1dz6FrhIVkM7QX0
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/kazu-yamamoto/crypton-certificate
synopsis:             Handle per-operating-system X.509 accessors and storage
description:
    System X.509 handling for accessing operating system dependents store and other storage methods

category:             Data
abi:                  2067094ed20fab1e8de209894e4be0db
exposed:              True
exposed-modules:      System.X509 System.X509.MacOS System.X509.Unix
import-dirs:          /usr/lib/ghc-9.6.6/site-local/crypton-x509-system-1.6.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/crypton-x509-system-1.6.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/crypton-x509-system-1.6.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-x509-system
hs-libraries:         HScrypton-x509-system-1.6.7-DQHBNlA1dz6FrhIVkM7QX0
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    crypton-x509-1.7.7-6vuhyPxGrsd7bUuwSROapz
    crypton-x509-store-1.6.12-Kpp5jEsJnJk1mLM8EMOCOC directory-1.3.8.5
    filepath-1.4.300.1 mtl-2.3.1 pem-0.2.4-G3GIG2bUe0L9P6z0Mw3OGw
    process-1.6.19.0

haddock-interfaces:
    /usr/share/doc/haskell-crypton-x509-system/html/crypton-x509-system.haddock

haddock-html:         /usr/share/doc/haskell-crypton-x509-system/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
